@@ -57,7 +57,7 @@ def get_translation(modname, dirname=None):
         _trans = gettext.translation(
             modname, get_module_locale_path(dirname), codeset="utf-8"
         )
-        lgettext = _trans.lgettext
+        lgettext = _trans.gettext
 
         def translate_gettext(x):
             if not PY3 and is_unicode(x):
@@ -105,8 +105,8 @@ def add_image_module_path(modname, relpath, subfolders=True):
     Appends image data path relative to a module name.
     Used to add module local data that resides in a module directory
     but will be shipped under sys.prefix / share/ ...
-    
-    modname must be the name of an already imported module as found in 
+
+    modname must be the name of an already imported module as found in
     sys.modules
     """
     add_image_path(get_module_data_path(modname, relpath=relpath), subfolders)
@@ -130,14 +130,22 @@ def get_image_file_path(name, default="not_found.png"):
         raise RuntimeError()
 
 
+ICON_CACHE = {}
+
+
 def get_icon(name, default="not_found.png"):
     """
     Construct a QIcon from the file with specified name
     name, default: filenames with extensions
     """
-    from qtpy import QtGui as QG
+    try:
+        return ICON_CACHE[name]
+    except KeyError:
+        from qtpy import QtGui as QG
 
-    return QG.QIcon(get_image_file_path(name, default))
+        icon = QG.QIcon(get_image_file_path(name, default))
+        ICON_CACHE[name] = icon
+        return icon
 
 
 def get_image_label(name, default="not_found.png"):
@@ -185,6 +193,11 @@ def font_is_installed(font):
 
 
 MONOSPACE = [
+    "Cascadia Code PL",
+    "Cascadia Mono PL",
+    "Cascadia Code",
+    "Cascadia Mono",
+    "Consolas",
     "Courier New",
     "Bitstream Vera Sans Mono",
     "Andale Mono",
@@ -284,4 +297,3 @@ def get_brush(conf, section, option="", color="black", alpha=1.0):
     alpha = conf.get(section, option + "/alphaF", alpha)
     color.setAlphaF(alpha)
     return QG.QBrush(color)
-
