@@ -16,6 +16,8 @@ easily Qt-based graphical user interfaces.
 from __future__ import print_function
 
 import sys
+import os
+import os.path as osp
 from qtpy.QtWidgets import (
     QAction,
     QApplication,
@@ -180,6 +182,43 @@ def add_actions(target, actions):
             add_separator(target)
 
 
+def _process_mime_path(path, extlist):
+    if path.startswith(r"file://"):
+        if os.name == "nt":
+            # On Windows platforms, a local path reads: file:///c:/...
+            # and a UNC based path reads like: file://server/share
+            if path.startswith(r"file:///"):  # this is a local path
+                path = path[8:]
+            else:  # this is a unc path
+                path = path[5:]
+        else:
+            path = path[7:]
+    path = path.replace("%5C", os.sep)  # Transforming backslashes
+    if osp.exists(path):
+        if extlist is None or osp.splitext(path)[1] in extlist:
+            return path
+
+
+def mimedata2url(source, extlist=None):
+    """
+    Extract url list from MIME data
+    extlist: for example ('.py', '.pyw')
+    """
+    pathlist = []
+    if source.hasUrls():
+        for url in source.urls():
+            path = _process_mime_path(str(url.toString()), extlist)
+            if path is not None:
+                pathlist.append(path)
+    elif source.hasText():
+        for rawpath in str(source.text()).splitlines():
+            path = _process_mime_path(rawpath, extlist)
+            if path is not None:
+                pathlist.append(path)
+    if pathlist:
+        return pathlist
+
+
 def get_std_icon(name, size=None):
     """
     Get standard platform icon
