@@ -9,17 +9,19 @@
 
 from __future__ import print_function
 
-SHOW = False # Do not show test in GUI-based test launcher
+SHOW = False  # Do not show test in GUI-based test launcher
 
 from guidata.dataset.datatypes import DataSet
 from guidata.dataset.dataitems import FloatItem, IntItem
 
+
 class Parameters(DataSet):
     height = FloatItem("Height", min=1, max=250, help="height in cm")
     width = FloatItem("Width", min=1, max=250, help="width in cm")
     number = IntItem("Number", min=3, max=20)
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     p = Parameters()
     p.text_edit()
-    print(p)
\ No newline at end of file
+    print(p)
