@@ -9,12 +9,12 @@
 
 from __future__ import print_function
 
-SHOW = False # Do not show test in GUI-based test launcher
+SHOW = False  # Do not show test in GUI-based test launcher
 
 from guidata.config import _
 
 translations = (_("Some required entries are incorrect"),)
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     for text in translations:
         print(text)
